best-before
===========

.. image:: https://travis-ci.org/paetzke/best-before.svg?branch=master
  :target: https://travis-ci.org/paetzke/best-before
.. image:: https://coveralls.io/repos/paetzke/best-before/badge.png?branch=master
  :target: https://coveralls.io/r/paetzke/best-before?branch=master
.. image:: https://pypip.in/v/best-before/badge.png
  :target: https://pypi.python.org/pypi/best-before/

Copyright (c) 2014, Friedrich Paetzke (paetzke@fastmail.fm)
All rights reserved.

